# Generated by Django 3.2.7 on 2021-09-16 23:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('textrank', '0003_group_description'),
    ]

    operations = [
        migrations.AlterField(
            model_name='group',
            name='name',
            field=models.CharField(error_messages={'unique': 'Такое название уже существует.'}, help_text='Обязательно. 150 символов и менее.', max_length=150, unique=True, verbose_name='название'),
        ),
    ]
