# Generated by Django 3.0.4 on 2021-09-15 05:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('textrank', '0002_sample'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='description',
            field=models.TextField(blank=True, db_index=True, verbose_name='описание'),
        ),
    ]
